@@ -41,7 +41,7 @@ class Letter(BaseEntity):
     Letter entity. Stores letter mailing logic.
     """
 
-    model = LetterModel  #type: LetterModel
+    model = LetterModel  # type: LetterModel
 
     @property
     def message(self) -> EmailMultiAlternatives:
@@ -96,7 +96,7 @@ class Letter(BaseEntity):
         else:
             self.set_sent()
 
-    def send(self, backend: Optional[CeleryEmailBackend]=None) -> None:
+    def send(self, backend: Optional[CeleryEmailBackend] = None) -> None:
         """
         Sends an email letter using the corresponding UseCase class.
         If not backend specified SendMailUseCase is used.
@@ -198,7 +198,7 @@ class Template(BaseEntity):
 
         return legend
 
-    def set_language(self, language: str=None) -> None:
+    def set_language(self, language: str = None) -> None:
         """
         Changes object language.
 
@@ -230,8 +230,12 @@ class Template(BaseEntity):
         """
 
         subject = DjangoTemplate(self.object.subject).render(Context(context))
-        html = DjangoTemplate(self.object.html).render(Context(context))
-        plain = DjangoTemplate(self.object.plain).render(Context(context))
+        html = DjangoTemplate(self.object.get_html()).render(Context(context))
+
+        if self.object.tilda_id:
+            plain = html
+        else:
+            plain = DjangoTemplate(self.object.plain).render(Context(context))
 
         return {
             'subject': subject,
@@ -240,12 +244,12 @@ class Template(BaseEntity):
         }
 
     def new_letter(
-            self,
-            context: Dict[str, Any],
-            recipients: List[str],
-            email_from: Optional[str]=None,
-            attachments: Optional[List]=None,
-            language: Optional[str]=None
+        self,
+        context: Dict[str, Any],
+        recipients: List[str],
+        email_from: Optional[str] = None,
+        attachments: Optional[List] = None,
+        language: Optional[str] = None
     ) -> Letter:
         """Creates new letter
 
@@ -268,13 +272,11 @@ class Template(BaseEntity):
             email_from = settings.DEFAULT_FROM_EMAIL
 
         letter = LetterModel.objects.create(
-            subject=rendered_fields['subject'],
-            html=rendered_fields['html'],
-            plain=rendered_fields['plain'],
             email_from=email_from,
             event=self.object.event,
             recipients=to_str(recipients),
-            language=language
+            language=language,
+            **rendered_fields
         )
         letter_entity = Letter(letter)
 
