@@ -9,7 +9,8 @@ __all__ = (
 
 def send_mail(
         event: str, recipients: List[str], context: Dict[Any, Any],
-        from_email: Optional[str]=None, attachments: Optional[List[Dict]]=None
+        from_email: Optional[str]=None, attachments: Optional[List[Dict]]=None,
+        language: str=None, backend=None
     ) -> Letter:
     """Shortcut to send email.
 
@@ -18,10 +19,14 @@ def send_mail(
         recipients (List[str]): Recipients email list.
         context (Dict[any, any]): Email context.
         from_email (Optional[str]): Sender email address.
-        attachments (Optional[List[str]]): Letter attachments
-        
+        attachments (Optional[List[str]]): Letter attachments.
+        language (str): Letter language.
+
     Raises:
         ValueError: No template found for given "event"
+
+    Returns:
+        Letter: New Letter entity.
     """
 
     if attachments is None:
@@ -29,9 +34,13 @@ def send_mail(
 
     template = Template.from_event(event)
     letter = template.new_letter(
-        context, recipients, from_email, attachments
+        context=context,
+        recipients=recipients,
+        email_from=from_email,
+        attachments=attachments,
+        language=language
     )
 
-    letter.send()
-    
+    letter.send(backend)
+
     return letter
